@@ -52,8 +52,8 @@ disambiguation, and in some cases warns.
 
 
 import os
-import string
 import sys
+import gzip
 from distutils.version import LooseVersion
 
 from vcstools.vcs_base import VcsClientBase, VcsError
@@ -92,8 +92,8 @@ def _git_diff_path_submodule_change(diff, rel_path_prefix):
                     newline = "+++ " + subrel_path + line[5:]
                 if line.startswith("diff --git"):
                     # first replacing b in case path starts with a/
-                    newline = string.replace(line, " b/", " " + subrel_path + "/", 1)
-                    newline = string.replace(newline, " a/", " " + subrel_path + "/", 1)
+                    newline = line.replace(" b/", " " + subrel_path + "/", 1)
+                    newline = newline.replace(" a/", " " + subrel_path + "/", 1)
         if newline != '':
             result += newline + '\n'
     return result
@@ -151,7 +151,10 @@ class GitClient(VcsClientBase):
         return None
 
     def detect_presence(self):
-        return self.path_exists() and os.path.isdir(os.path.join(self._path, '.git'))
+        # There is a proposed implementation of detect_presence which might be
+        # more future proof, but would depend on parsing the output of git
+        # See: https://github.com/vcstools/vcstools/pull/10
+        return self.path_exists() and os.path.exists(os.path.join(self._path, '.git'))
 
     def checkout(self, url, refname=None, verbose=False, shallow=False):
         """calls git clone and then, if refname was given, update(refname)"""
@@ -171,7 +174,7 @@ class GitClient(VcsClientBase):
             return False
 
         if refname is not None and refname != "master":
-            return self.update(refname)
+            return self.update(refname, verbose=verbose)
         else:
             return True
 
@@ -190,9 +193,15 @@ class GitClient(VcsClientBase):
         return True
 
     def update(self, refname=None, verbose=False):
-        """interprets refname as a local branch, remote branch, tagname, hash, etc.
-        If it is a branch, attempts to move to it unless already on it, and to fast-forward, unless not a tracking branch.
-        Else go untracked on tag or whatever refname is. Does not leave if current commit would become dangling."""
+        """
+        interprets refname as a local branch, remote branch, tagname,
+        hash, etc.
+
+        If it is a branch, attempts to move to it unless
+        already on it, and to fast-forward, unless not a tracking
+        branch. Else go untracked on tag or whatever refname is. Does
+        not leave if current commit would become dangling.
+        """
         # try calling git fetch just once per call to update()
         need_to_fetch = True
         if not self.detect_presence():
@@ -210,7 +219,7 @@ class GitClient(VcsClientBase):
             refname = branch_parent
         if refname is None:
             # we are neither tracking, nor did we get any refname to update to
-            return self.update_submodules()
+            return self.update_submodules(verbose=verbose)
 
         # local branch might be named differently from remote by user, we respect that
         same_branch = (refname == branch_parent) or (refname == current_branch)
@@ -236,7 +245,7 @@ class GitClient(VcsClientBase):
 
             # shortcut if version is the same as requested
             if not refname_is_branch and self.get_version() == refname:
-                return self.update_submodules()
+                return self.update_submodules(verbose=verbose)
 
             if current_branch is None:
                 current_version = self.get_version()
@@ -250,7 +259,10 @@ class GitClient(VcsClientBase):
                 need_to_fetch = False
 
             # git checkout makes all the decisions for us
-            self._do_checkout(refname, fetch=need_to_fetch, verbose=verbose)
+            checkout_result = self._do_checkout(refname, fetch=need_to_fetch,
+                                                verbose=verbose)
+            if not checkout_result:
+                return checkout_result
             need_to_fetch = False
 
             if refname_is_local_branch:
@@ -261,7 +273,7 @@ class GitClient(VcsClientBase):
                                                  verbose=verbose):
                         return False
 
-        return self.update_submodules()
+        return self.update_submodules(verbose=verbose)
 
     def get_version(self, spec=None):
         """
@@ -292,6 +304,8 @@ class GitClient(VcsClientBase):
                 # we try again after fetching if given spec had not been found
                 self._do_fetch()
                 repeated = True
+            # On Windows the version can have single quotes around it
+            output = output.strip("'")
             return output
         return None
 
@@ -517,11 +531,27 @@ class GitClient(VcsClientBase):
                 cmd += " --pretty=format:%H"
             _, output, _ = run_shell_command(cmd, shell=True, cwd=self._path)
             for line in output.splitlines():
-                if line.startswith(version):
+                if line.strip("'").startswith(version):
                     return False
             return True
         return False
 
+    def export_repository(self, version, basepath):
+        # Use the git archive function
+        cmd = "git archive -o {0}.tar {1}".format(basepath, version)
+        result, _, _ = run_shell_command(cmd, shell=True, cwd=self._path)
+        if result:
+            return False
+        # Gzip the tar file
+        tar_file = open(basepath + '.tar', 'rb')
+        gzip_file = gzip.open(basepath + '.tar.gz', 'wb')
+        gzip_file.writelines(tar_file)
+        tar_file.close()
+        gzip_file.close()
+        # Clean up
+        os.remove(basepath + '.tar')
+        return True
+
     def _do_fetch(self):
         """calls git fetch"""
         value, _, _ = run_shell_command("git fetch",
@@ -535,9 +565,11 @@ class GitClient(VcsClientBase):
         do so to the last fetched version using git rebase. Returns
         False on command line failures"""
         parent = self.get_branch_parent(fetch=fetch)
-        if parent is not None and self.rev_list_contains("remotes/origin/%s"%parent,
+        if parent is not None and self.rev_list_contains("remotes/origin/%s" % parent,
                                                          self.get_version(),
                                                          fetch=False):
+            if verbose:
+                print("Rebasing repository")
             # Rebase, do not pull, because somebody could have
             # commited in the meantime.
             if LooseVersion(self.gitversion) >= LooseVersion('1.7.1'):
@@ -586,8 +618,8 @@ class GitClient(VcsClientBase):
                                         show_stdout=verbose,
                                         verbose=verbose)
         if value == 0:
-            return False
-        return True
+            return True
+        return False
 
 #Backwards compatability
 GITClient = GitClient
