@@ -39,7 +39,8 @@ using ui object to redirect output into a string
 
 import os
 import sys
-import string
+
+import gzip
 
 from vcstools.vcs_base import VcsClientBase, VcsError
 from vcstools.common import sanitized, normalized_rel_path, run_shell_command
@@ -55,9 +56,9 @@ def _get_hg_version():
         if value == 0 and output is not None and len(output.splitlines()) > 0:
             version = output.splitlines()[0]
         else:
-            raise VcsError("hg --version returned %s, maybe hg is not installed"%value)
+            raise VcsError("hg --version returned %s, output '%s', maybe hg is not installed" % (value, output))
     except VcsError as e:
-        raise VcsError("Could not determine whether hg is installed %s"%e)
+        raise VcsError("Could not determine whether hg is installed %s" % e)
     return version
 
 
@@ -85,13 +86,13 @@ def _hg_diff_path_change(diff, path):
                 newline = line
             else:
                 if line.startswith("---") and not line.startswith("--- /dev/null"):
-                    newline = "--- %s%s"%(path, line[5:])
+                    newline = "--- %s%s" % (path, line[5:])
                 elif line.startswith("+++") and not line.startswith("+++ /dev/null"):
-                    newline = "+++ %s%s"%(path, line[5:])
+                    newline = "+++ %s%s" % (path, line[5:])
                 elif line.startswith("diff --git"):
                     # first replacing b in case path starts with a/
-                    newline = string.replace(line, " b/", " " + path + "/", 1)
-                    newline = string.replace(newline, " a/", " " + path + "/", 1)
+                    newline = line.replace(" b/", " " + path + "/", 1)
+                    newline = newline.replace(" a/", " " + path + "/", 1)
                 else:
                     newline = line
         else:
@@ -115,7 +116,7 @@ class HgClient(VcsClientBase):
     def get_environment_metadata():
         metadict = {}
         try:
-            metadict["version"] = '%s'%_get_hg_version()
+            metadict["version"] = '%s' % _get_hg_version()
         except:
             metadict["version"] = "no mercurial installed"
         return metadict
@@ -149,22 +150,20 @@ class HgClient(VcsClientBase):
         except OSError:
             # OSError thrown if directory already exists this is ok
             pass
-        cmd = "hg clone %s %s"%(sanitized(url), self._path)
+        cmd = "hg clone %s %s" % (sanitized(url), self._path)
         value, _, _ = run_shell_command(cmd,
                                         shell=True,
-                                        show_stdout=verbose,
-                                        verbose=verbose)
+                                        no_filter=True)
         if value != 0:
             if self.path_exists():
                 sys.stderr.write("Error: cannot checkout into existing directory\n")
             return False
         if version is not None and version.strip() != '':
-            cmd = "hg checkout %s"%sanitized(version)
+            cmd = "hg checkout %s" % sanitized(version)
             value, _, _ = run_shell_command(cmd,
                                             cwd=self._path,
                                             shell=True,
-                                            show_stdout=verbose,
-                                            verbose=verbose)
+                                            no_filter=True)
             if value != 0:
                 return False
         return True
@@ -179,14 +178,13 @@ class HgClient(VcsClientBase):
         if not self._do_pull():
             return False
         if version is not None and version.strip() != '':
-            cmd = "hg checkout %s %s"%(verboseflag, sanitized(version))
+            cmd = "hg checkout %s %s" % (verboseflag, sanitized(version))
         else:
-            cmd = "hg update %s --config ui.merge=internal:fail"%verboseflag
+            cmd = "hg update %s --config ui.merge=internal:fail" % verboseflag
         value, _, _ = run_shell_command(cmd,
                                         cwd=self._path,
                                         shell=True,
-                                        show_stdout=True,
-                                        verbose=verbose)
+                                        no_filter=True)
         if value != 0:
             return False
         return True
@@ -203,7 +201,7 @@ class HgClient(VcsClientBase):
         # detect presence only if we need path for cwd in popen
         if spec is not None:
             if self.detect_presence():
-                command = 'hg log -r %s'%sanitized(spec)
+                command = 'hg log -r %s' % sanitized(spec)
                 repeated = False
                 output = ''
                 # we repeat the call once after pullin if necessary
@@ -220,13 +218,13 @@ class HgClient(VcsClientBase):
                         if len(matches) == 1:
                             return matches[0].split(':')[2]
                         else:
-                            sys.stderr.write("Warning: found several candidates for hg spec %s"%spec)
+                            sys.stderr.write("Warning: found several candidates for hg spec %s" % spec)
                         break
                     self._do_pull()
                     repeated = True
             return None
         else:
-            command = 'hg identify -i %s'%self._path
+            command = 'hg identify -i %s' % self._path
             _, output, _ = run_shell_command(command, shell=True, us_env=True)
             if output is None or output.strip() == '' or output.startswith("abort"):
                 return None
@@ -240,7 +238,7 @@ class HgClient(VcsClientBase):
             basepath = self._path
         if self.path_exists():
             rel_path = normalized_rel_path(self._path, basepath)
-            command = "hg diff -g %s"%(sanitized(rel_path))
+            command = "hg diff -g %s" % (sanitized(rel_path))
             _, response, _ = run_shell_command(command, shell=True, cwd=basepath)
             response = _hg_diff_path_change(response, rel_path)
         return response
@@ -252,7 +250,7 @@ class HgClient(VcsClientBase):
         if self.path_exists():
             rel_path = normalized_rel_path(self._path, basepath)
             # protect against shell injection
-            command = "hg status %s"%(sanitized(rel_path))
+            command = "hg status %s" % (sanitized(rel_path))
             if not untracked:
                 command += " -mard"
             _, response, _ = run_shell_command(command,
@@ -260,16 +258,32 @@ class HgClient(VcsClientBase):
                                                cwd=basepath)
             if response is not None:
                 if response.startswith("abort"):
-                    raise VcsError("Probable Bug; Could not call %s, cwd=%s"%(command, basepath))
+                    raise VcsError("Probable Bug; Could not call %s, cwd=%s" % (command, basepath))
                 if len(response) > 0 and response[-1] != '\n':
                     response += '\n'
         return response
 
+    def export_repository(self, version, basepath):
+        # execute the hg archive cmd
+        cmd = 'hg archive -t tar -r {0} {1}.tar'.format(version, basepath)
+        result, _, _ = run_shell_command(cmd, shell=True, cwd=self._path)
+        if result:
+            return False
+        # gzip the tar file
+        tar_file = open(basepath + '.tar', 'rb')
+        gzip_file = gzip.open(basepath + '.tar.gz', 'wb')
+        gzip_file.writelines(tar_file)
+        tar_file.close()
+        gzip_file.close()
+        # clean up
+        os.remove(basepath + '.tar')
+        return True
+
     def _do_pull(self):
         value, _, _ = run_shell_command("hg pull",
                                         cwd=self._path,
                                         shell=True,
-                                        show_stdout=True)
+                                        no_filter=True)
         return value == 0
 
 # backwards compat
