@@ -122,7 +122,7 @@ class VcsClientBase(object):
         after a failed call to checkout, a repository still exists,
         e.g. if an invalid revision spec was given.
         If shallow is provided, the scm client may checkout less
-        than the full repository history to svae time / disk space.
+        than the full repository history to save time / disk space.
 
         :param url: where to checkout from
         :type url: str
@@ -180,3 +180,12 @@ class VcsClientBase(object):
         """
         raise NotImplementedError("Base class get_status method must be overridden")
 
+    def export_repository(self, version, basepath):
+        """
+        Calls scm equivalent to `svn export`, removing scm meta information and tar gzip'ing the repository at a given version to the given basepath.
+
+        :param version: version of the repository to export.  This can be a branch, tag, or path (svn).  When specifying the version as a path for svn, the path should be relative to the root of the svn repository, i.e. 'trunk', or 'tags/1.2.3', or './' for the root.
+        :param basepath: this is the path to the tar gzip, excluding the extension which will be .tar.gz
+        :returns: True on success, False otherwise.
+        """
+        raise NotImplementedError("Base class export_repository method must be overridden")
